from .methods import compile, findall, match, scan, split, substitute
from .consts import (
    __libpcre2_version__,
    CompileOption,
    A, I, M, U, S, X
)
__version__ = "0.4.0"
